# Application Settings

> Configure application-level settings for OpenHands.

## Overview

The Application settings allows you to customize various application-level behaviors in OpenHands, including
language preferences, notification settings, custom Git author configuration and more.

## Setting Maximum Budget Per Conversation

To limit spending, go to `Settings > Application` and set a maximum budget per conversation (in USD)
in the `Maximum Budget Per Conversation` field. OpenHands will stop the conversation once the budget is reached, but
you can choose to continue the conversation with a prompt.

## Git Author Settings

OpenHands provides the ability to customize the Git author information used when making commits and creating
pull requests on your behalf.

By default, OpenHands uses the following Git author information for all commits and pull requests:

* **Username**: `openhands`
* **Email**: `openhands@all-hands.dev`

To override the defaults:

1. Navigate to the `Settings > Application` page.
2. Under the `Git Settings` section, enter your preferred `Git Username` and `Git Email`.
3. Click `Save Changes`

<Note>
  When you configure a custom Git author, OpenHands will use your specified username and email as the primary author
  for commits and pull requests. OpenHands will remain as a co-author.
</Note>


---

> To find navigation and other pages in this documentation, fetch the llms.txt file at: https://docs.openhands.dev/llms.txt